==> wildfly-server-18.1.2.Final-sources.jar: org/jboss/as/server/services/net/InterfaceAddHandler.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2015, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.server.services.net;

/**
 * TODO remove this once we can get the superclass out of the controller module to a place
 * where the NetworkInterface class is visible.
 *
 * @author Brian Stansberry
 */
public class InterfaceAddHandler extends org.jboss.as.controller.operations.common.InterfaceAddHandler {

    public static final InterfaceAddHandler NAMED_INSTANCE = new InterfaceAddHandler(false);

    /**
     * Create the InterfaceAddHandler
     *
     * @param specified
     */
    InterfaceAddHandler(boolean specified) {
        // Pass the capability through the OSH constructor rather than relying
        // on the MRR, as in some subsystem test stuff due to restrictions for
        // legacy controllers the MRR can't record the cap
        super(specified, InterfaceResourceDefinition.INTERFACE_CAPABILITY);
    }

}

==> wildfly-server-21.1.1.Final-sources.jar: org/jboss/as/server/services/net/InterfaceAddHandler.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2015, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.server.services.net;

/**
 * TODO remove this once we can get the superclass out of the controller module to a place
 * where the NetworkInterface class is visible.
 *
 * @author Brian Stansberry
 */
public class InterfaceAddHandler extends org.jboss.as.controller.operations.common.InterfaceAddHandler {

    public static final InterfaceAddHandler NAMED_INSTANCE = new InterfaceAddHandler(false);

    /**
     * Create the InterfaceAddHandler
     *
     * @param specified {@code true} if the interface is expected to have a specified interface selection criteria;
     *                  {@code false} if the interface can simply be a named placeholder
     */
    InterfaceAddHandler(boolean specified) {
        super(specified);
    }

}
